import { 
  select,csv,
  scaleLinear, extent,
  axisLeft,axisBottom,format
} from 'd3';

export const scatterplot=(selection, props)=>{
  const {
    data,
    circleRadius,
    colorScale,
    colorValue,
    selectedCountry,
    innerWidth,
    innerHeight} = props;
  
 
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  const yValue = d => d.gdp;
  const yAxisLabel = 'GDP (In Percent)';
  
  //const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  //const innerWidth = width - margin.left-margin.right;
  //const innerHeight = height - margin.top - margin.bottom;
  
  
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
    
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  
    //const g = svg.append('g')
    //.attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  const xAxis = axisBottom(xScale)
    .ticks(10)
    .tickSize(-innerHeight)
    .tickPadding(15)
    .tickFormat(format("d"));
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  
  const yAxisG = selection.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -55)
      .attr('x', -innerHeight / 2)
      .attr('fill', '#3a3333')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  
  const xAxisG = selection.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 55)
      .attr('x', innerWidth / 2)
      .attr('fill', '#3a3333')
      .text(xAxisLabel);
  
  //correct placement of enter and merge statements: From Nick lima
  const points = selection.selectAll('.artist').data(data);
  const pointsEnter = points
    .enter().append('circle')
      .attr('class', 'artist')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('stroke-width',0.6)
      .attr('stroke','black')
      .attr('fill', d => colorScale(d.country));
   points.merge(pointsEnter)
      .attr('opacity', d =>
        (!selectedCountry || d.country === selectedCountry) ? 1 : 0.05);
};

/*
csv('https://vizhub.com/MukundKhandelwal/datasets/us_scatterplot.csv')
  .then(data => {
    data.forEach(d => {
      d.year = +d.year;
      d.revenue = +d.revenue;
      d.expenditure = +d.expenditure;
      d.gdp = +d.gdp;
      d.debt = +d.debt;  
    });
    render(data);
  });*/
